@@ -107,7 +107,8 @@ class Highlight(RestCall):
             # retrieve all applications from HL REST API
             Highlight._apps_full_list = DataFrame(self._get_applications())
 #            Highlight._apps_full_list.dropna(subset=['metrics'],inplace=True)
-            self.info(f'Found {len(Highlight._apps_full_list)} analyzed applications: {",".join(Highlight._apps_full_list["name"])}')
+#            self.info(f'Found {len(Highlight._apps_full_list)} analyzed applications: {",".join(Highlight._apps_full_list["name"])}')
+            self.info(f'Found {len(Highlight._apps_full_list)} analyzed applications')
     
             # if the apps is not already of list type then convert it now
             if not isinstance(hl_apps,list):
@@ -132,7 +133,7 @@ class Highlight(RestCall):
     def _get_application_data(self,app:str=None):
         self.debug('Retrieving all HL application specific data')
         
-        if str is None:
+        if app is None:
             df = Highlight._apps
         else:
             df = Highlight._apps[Highlight._apps['name']==app]
@@ -170,7 +171,7 @@ class Highlight(RestCall):
         if app_name not in Highlight._apps['name'].to_list():
             raise ValueError(f'{app_name} is not a selected application')
 
-        if str is None:
+        if app_name is None:
             df = Highlight._apps
         else:
             df = Highlight._apps[Highlight._apps['name']==app_name]
@@ -352,13 +353,16 @@ class Highlight(RestCall):
 
     def get_cve_critical(self, app_name:str) -> DataFrame:
         cves = self.get_cve_data(app_name)
-        return cves[cves['criticity']=='CRITICAL']
+        if not cves.empty:
+            return cves[cves['criticity']=='CRITICAL']
     def get_cve_high(self, app_name:str) -> DataFrame:
         cves = self.get_cve_data(app_name)
-        return cves[cves['criticity']=='HIGH']
+        if not cves.empty:
+            return cves[cves['criticity']=='HIGH']
     def get_cve_medium(self, app_name:str) -> DataFrame:
         cves = self.get_cve_data(app_name)
-        return cves[cves['criticity']=='MEDIUM']
+        if not cves.empty:
+            return cves[cves['criticity']=='MEDIUM']
 
     def get_license_data(self,app_name:str) -> DataFrame:
         third_party = self._get_third_party(app_name)['thirdParties']
@@ -391,14 +395,20 @@ class Highlight(RestCall):
 
     def get_license_high(self,app_name:str) -> DataFrame:
         lic = self.get_license_data(app_name)
+        if lic.empty:
+            return DataFrame()
         return lic[lic['compliance']=='high'] 
 
     def get_license_medium(self,app_name:str) -> DataFrame:
         lic = self.get_license_data(app_name)
+        if lic.empty:
+            return DataFrame()
         return lic[lic['compliance']=='medium']   
 
     def get_license_low(self,app_name:str) -> DataFrame:
         lic = self.get_license_data(app_name)
+        if lic.empty:
+            return DataFrame()
         return lic[lic['compliance']=='low']   
 
     """ **************************************************************************************************************
@@ -481,7 +491,7 @@ class Highlight(RestCall):
         for app in app_list:
             metrics = self._get_metrics(app)
             for key in self.grades:
-                if metrics[key] is not None: 
+                if key in metrics and metrics[key] is not None: 
                     t_scores[key]+=metrics[key]
 
         t_apps = len(app_list)
