@@ -1,18 +1,23 @@
 from cast_common.restAPI import RestCall
-from cast_common.logger import INFO
 from requests import codes, post
-from pandas import DataFrame,json_normalize,concat
+from pandas import DataFrame
+from pandas import json_normalize
+from pandas import concat
+from logging import DEBUG, INFO, ERROR, warning
 
-__author__ = "Nevin Kaplan"
-__email__ = "n.kaplan@castsoftware.com"
-__copyright__ = "Copyright 2022, CAST Software"
 
 class HLRestCall(RestCall):
     """
     Class to handle HL REST API calls.
     """
-    def __init__(self, hl_base_url, hl_user, hl_pswd, hl_instance, timer_on=False,log_level=INFO):
-        super().__init__(hl_base_url, hl_user, hl_pswd, timer_on,log_level,accept_json=False)
+    def __init__(self, hl_base_url:str, hl_user:str, hl_pswd:str, hl_instance:int, timer_on=False,log_level=INFO):
+
+        if hl_base_url.endswith('/'):
+            hl_base_url = hl_base_url[:-1]
+        if not hl_base_url.endswith(r'/WS2'):
+            hl_base_url=f'{hl_base_url}/WS2'
+
+        super().__init__(base_url=hl_base_url,user=hl_user,password=hl_pswd,track_time=timer_on,log_level=log_level)
 
         self._hl_instance = hl_instance
         self._hl_data_retrieved = False
@@ -121,15 +126,20 @@ class HLRestCall(RestCall):
                     load_df_element(tp,lic_df,'lastVersion')
                     lic=concat([lic,lic_df],ignore_index=True)
 
-            if 'component' in cves.columns:
+            if not cves.empty and 'component' in cves.columns:
                 cves=cves[['component','version','languages','release','origin','lastVersion','cve', 'description', 'cweId', 'cweLabel', 'criticity', 'cpe']]
-            if 'component' in lic.columns:
+            else:
+                cves=None
+                
+            if not lic.empty and  'component' in lic.columns:
                 lic=lic[['component','version','languages','release','origin','lastVersion','license','compliance']] 
+            else:
+                lic=None
 
         return lic,cves,len(third_party)
     
-    def create_an_app(self, url, instance_id, app_name):
-        url = f'{url}/domains/{instance_id}/applications/'
+    def create_an_app(self, instance_id, app_name):
+        url = f'{self._base_url}/domains/{instance_id}/applications/'
         payload =[{"name": app_name,"domains": [{"id": instance_id}]}]
 
         resp = post(url, auth=self._auth, json=payload)        
